<?php

if ( ! function_exists( 'nonprofit_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 */
	function nonprofit_setup() {
		/*
		 * Make theme available for translation.
		 */
		load_theme_textdomain( 'nonprofit', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'post_737x839', 737,839, true );
		add_image_size( 'team_720x615', 720,615, true );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary menu', 'nonprofit' ),
			'menu-2' => esc_html__( 'Right menu', 'nonprofit' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'nonprofit_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'nonprofit_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 */
function nonprofit_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'nonprofit_content_width', 640 );
}
add_action( 'after_setup_theme', 'nonprofit_content_width', 0 );

/**
 * Register widget area.
 */
function nonprofit_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'nonprofit' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'nonprofit' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h5 class="widget-title text-uppercase">',
		'after_title'   => '</h5>',
	) );
}
add_action( 'widgets_init', 'nonprofit_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function nonprofit_scripts() {
	/**
	 * Enqueue styles.
	 */
	wp_enqueue_style('plugins', get_template_directory_uri() . '/css/plugins.css', array(), false, 'all');
	wp_enqueue_style( 'nonprofit-style', get_stylesheet_uri() );


	/**
	 * Enqueue scripts.
	 */
	wp_enqueue_script('jquery');
	wp_enqueue_script('fonts', 'https://use.typekit.net/usn8tqd.js', array(), false, true);
	wp_enqueue_script('plugins', get_template_directory_uri() . '/js/plugins.js', array(), false, true);
	$gmap_api = get_field('google_map_api_key', 'options');
	$googleapi = "https://maps.googleapis.com/maps/api/js?key=$gmap_api";
	wp_enqueue_script('gmap_api', $googleapi, array(), false, true);
	wp_enqueue_script('scripts', get_template_directory_uri() . '/js/scripts.js', array(), false, true);

	$map_icon = get_field('map_pin', 'options');
	$google_map = get_field('google_map');

	$data = array(
		'sticky_menu' => get_field('sticky_menu', 'options'),
		'gmap_latitude' => $google_map['lat'],
		'gmap_longitude' => $google_map['lng'],
		'gmap_address' => $google_map['address'],
		'map_icon' => $map_icon,
	);
	wp_localize_script('scripts', 'ajax', $data);

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'nonprofit_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/navwalker.php';


function nonprofit_body_classes( $classes ) {
	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	return $classes;
}
add_filter( 'body_class', 'nonprofit_body_classes' );

/**
 * ACF OPTIONS PAGE
 *
 */
if(function_exists('acf_add_options_page')) {
    acf_add_options_page();
}

/**
 * Dashboard google map api key support.
 */
add_filter('acf/settings/google_api_key', function () {
	$gmap_api = get_field('google_map_api_key', 'options');
    return $gmap_api;
});

/**
 * Custom css
 *
 */ 
function nonprofit_admin_custom_css() {
    echo '<style type="text/css">
    	#acf-group_5991ba321c24d .hndle {background: url('.get_template_directory_uri().'/images/header-bg.png) repeat-x; padding-top: 0px;} #acf-group_5991ba321c24d .hndle span img {width: 90px;}
	</style>';
}
add_action('admin_head', 'nonprofit_admin_custom_css');

/**
 * Pagination
 *
 */
if ( !function_exists( 'nonprofit_pagination' ) ) {
	
	function nonprofit_pagination() {
		
		the_posts_pagination(array(
		   'prev_next' => false,
		   'prev_text' => '<',
		   'next_text' => '>',
		   'screen_reader_text' => '',
		   'before_page_number' => '',
		   'after_page_number' => '',
		   'show_all' => false
		  )); 
	}
	
}

/**
 * Limit blog text
 *
 */
function Limit_Text($x, $length) {
	if(strlen($x)<=$length) {
		echo $x;
	} else {
		$y=substr($x,0,$length) . '...';
		echo $y;
	}
}

/**
 * Get all page id
 *
 */ 
function getPageID() {
	global $post;
	$postid = $post->ID;
	if(is_home() && get_option('page_for_posts')) {
		$postid = get_option('page_for_posts');
	}

	return $postid;
}

/**
 * ACF not working use jquery
 *
 */
function hide_editor_custom_js() {
    echo '<script type="text/javascript">
			jQuery(document).ready(function(){
				jQuery("#page_template").change( function() {
					jQuery("#_home_page_options").hide();
					jQuery("#postdivrich").show();
					switch( jQuery( this ).val() ) {
						case "t_programs.php":
				          jQuery("#_home_page_options").show();
				          jQuery("#postdivrich").hide();

				        break;

				        case "t_home.php":
				          jQuery("#_home_page_options").show();
				          jQuery("#postdivrich").hide();

				        break;

				        case "t_donate.php":
				          jQuery("#_home_page_options").show();
				          jQuery("#postdivrich").hide();

				        break;

				        case "t_contact.php":
				          jQuery("#_home_page_options").show();
				          jQuery("#postdivrich").hide();

				        break;

				        case "t_about.php":
				          jQuery("#_home_page_options").show();
				          jQuery("#postdivrich").hide();

				        break;
					}
				}).change();
			});
		</script>';
}
add_action('admin_head', 'hide_editor_custom_js');

/*function remove_admin_menus() {
	remove_menu_page( 'themes.php' );               			// Appearance
	remove_menu_page( 'edit-comments.php' );      				// Comments
	remove_menu_page( 'users.php' );                			// Users
	remove_menu_page( 'tools.php' );                			// Tools
	remove_menu_page( 'options-general.php' );      			// Settings
	remove_menu_page( 'plugins.php' );              			// Plugings
	remove_menu_page( 'edit.php?post_type=acf-field-group' );	// Custom Field 
}
add_action( 'admin_menu', 'remove_admin_menus' );*/

function reorder_admin_menu( $__return_true ) {
    return array(
         'index.php', 					// Dashboard
         'separator1', 					// --Space--
         'acf-options',					// ACF Theme Settings
         'edit.php?post_type=page', 	// Pages 
         'edit.php', 					// Posts
         'separator2', 					// --Space--
         'gf_edit_forms',				// Gravity Forms
         'upload.php', 					// Media
         'wpseo_dashboard',				// Yoasta
         'gadash_settings',				// Google Analytics
         'themes.php', 					// Appearance
         'edit-comments.php', 			// Comments 
         'users.php', 					// Users
         'tools.php', 					// Tools
         'options-general.php', 		// Settings
         'plugins.php', 				// Plugins
   );
}
add_filter( 'custom_menu_order', 'reorder_admin_menu' );
add_filter( 'menu_order', 'reorder_admin_menu' );


/* customize login screen */
function nonprofit_images_custom_login_page() {
    echo '<style type="text/css">
        h1 a { background-image:url("'. get_stylesheet_directory_uri().'/images/logo.png") !important; height: 100px !important; width: 100% !important; margin: 0 auto !important; background-size: contain !important; }
		h1 a:focus { outline: 0 !important; box-shadow: none; }
        body.login { background-image:url("'. get_stylesheet_directory_uri().'/images/banner.png") !important; background-repeat: no-repeat !important; background-attachment: fixed !important; background-position: center !important; background-size: cover !important; position: relative; z-index: 999;}
  		body.login:before { background-color: rgba(0,0,0,0.7); position: absolute; width: 100%; height: 100%; left: 0; top: 0; content: ""; z-index: -1; }
  		.login form {
  			background: rgba(255,255,255, 0.2) !important;
  		}
		.login form .input, .login form input[type=checkbox], .login input[type=text] {
			background: transparent !important;
			color: #ddd;
		}
		.login label {
			color: #DDD !important;
		}
		.login #login_error, .login .message {
			color: #ddd;
			margin-top: 20px;
			background: rgba(255,255,255, 0.2) !important;
		}
    </style>';
}
add_action('login_head', 'nonprofit_images_custom_login_page');

function nonprofit_login_logo_url_title() {
 	return 'Business Simple';
}
add_filter( 'login_headertitle', 'nonprofit_login_logo_url_title' );

function nonprofit_login_logo_url() {
	return get_bloginfo( 'url' );
}
add_filter( 'login_headerurl', 'nonprofit_login_logo_url' );